@@ -25,21 +25,23 @@ class GermanDPR(AbsTaskRetrieval):
         eval_splits=[_EVAL_SPLIT],
         eval_langs=["deu-Latn"],
         main_score="ndcg_at_10",
-        date=None,
-        domains=None,
-        task_subtypes=None,
-        license=None,
-        annotations_creators=None,
-        dialect=None,
-        sample_creation=None,
-        bibtex_citation="""@misc{möller2021germanquad,
-      title={GermanQuAD and GermanDPR: Improving Non-English Question Answering and Passage Retrieval}, 
-      author={Timo Möller and Julian Risch and Malte Pietsch},
-      year={2021},
-      eprint={2104.12741},
-      archivePrefix={arXiv},
-      primaryClass={cs.CL}
-}""",
+        date=("2020-05-19", "2021-04-26"),
+        domains=["Written", "Non-fiction", "Web"],
+        task_subtypes=["Question answering"],
+        license="cc-by-4.0",
+        annotations_creators="human-annotated",
+        dialect=[],
+        sample_creation="found",
+        bibtex_citation=r"""
+@misc{möller2021germanquad,
+  archiveprefix = {arXiv},
+  author = {Timo Möller and Julian Risch and Malte Pietsch},
+  eprint = {2104.12741},
+  primaryclass = {cs.CL},
+  title = {GermanQuAD and GermanDPR: Improving Non-English Question Answering and Passage Retrieval},
+  year = {2021},
+}
+""",
     )
 
     @staticmethod
@@ -82,7 +84,7 @@ class GermanDPR(AbsTaskRetrieval):
                 existing_docs=all_docs,
             )
             corpus.update(neg_docs)
-            relevant_docs[q_id] = {k: 1 for k in pos_docs}
+            relevant_docs[q_id] = dict.fromkeys(pos_docs, 1)
         corpus = {
             key: doc.get("title", "") + " " + doc["text"] for key, doc in corpus.items()
         }
